<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Flugmodus aktiviert</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Flugmodus deaktiviert</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Deaktivieren</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Deaktivieren</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Flugmodus</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Flugmodus-Einstellungen</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Flugmodus</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Meine Geräte</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth-Einstellungen</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Ausgeschaltet</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation>Zuerst den [Flugmodus](#) ausschalten, wenn Sie sich über Bluetooth verbinden wollen</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Ausschalten</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Einschalten</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth-Einstellungen</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 verbunden</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Verbinden...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Ausgeschaltet</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Verbunden %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nicht verbunden</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Aus</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Helligkeit</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Anzeige-Einstellungen</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Anzeige-Einstellungen</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Helligkeit</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Son</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>on</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Die</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Mit</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Don</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Fre</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Sam</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Füge Tastatur-Layout hinzu</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-Stunden-Zeit</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-Stunden-Zeit</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Zeit-Einstellungen</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Kalender öffnen</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sonntag</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>Sonntag</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Andere Geräte</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Nicht-Stören-Modus</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Nicht-Stören-Modus-Einstellungen</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Deaktivieren</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Nicht-Stören-Modus aktiviert</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Nicht-Stören-Modus deaktiviert</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Nicht-Stören-Modus</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Augenschonung</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Augen-schonen aktiviert</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Augen-schonen deaktiviert</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Anzeige-Einstellungen</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Augenschonung</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Design</translation>
    </message>
    <message>
        <source>On</source>
        <translation>An</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Aus</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Hell</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Dunkel</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Augenschonen abwählen</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Augenschonen</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Anzeige-Einstellungen</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Design: hell</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Design: Dunkel</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Design: Auto</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Nachtmodus</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Hell</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Dunkel</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Design</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Keine Nachricht</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Mitteilungs-Einstellungen</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Nicht-Stören-Modus ausschalten</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Nicht-Stören-Modus einschalten</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Benachrichtigung</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Bildschirmtastatur</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Volle Rechenpower</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Ausgeglichen</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Energiesparen</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Ausgeglichene Leistung</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Energie</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Energie-Einstellungen</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Kapazität %1, %2 Min. verbleiben</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Kapazität %1, %2 Std %3 Min. verbleiben.</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Lädt %1, %2 Min. bis voll geladen</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Lädt %1, %2 Std %3 Min bis voll geladen</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapazität %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Lädt %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapazität %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapazität %1, voll geladen</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Kapazität %1, lädt nicht</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Akku</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Lädt, geschätzte Ladedauer wird berechnet</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Verbleibende Nutzungsdauer wird berechnet</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 Min verbleiben</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 Std %2 Min verbleiben</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Lädt nicht</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Voll geladen</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Lädt, %1 Min bis voll geladen</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Lädt %1 Std %2 Min. bis voll geladen</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Kapazität %1, %2 Std. verbleiben</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 Std verbleibend</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Lädt %1, %2 Std. bis voll geladen</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Lädt, %1 Std bis voll geladen</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Energie-Einstellungen</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Bereitschaft</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ruhezustand</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Sperren</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Abmelden</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energieeinstellungen</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Neustart</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Aktualisieren und herunterfahren</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Aktualisieren und neustarten</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Benutzer wechseln</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Heute</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Lunar</translation>
    </message>
    <message>
        <source>y</source>
        <translation>J</translation>
    </message>
    <message>
        <source>m</source>
        <translation>M</translation>
    </message>
    <message>
        <source>d</source>
        <translation>T</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sonntag</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Jan</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Feb</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Mär</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Apr</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Mai</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Juni</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Juli</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Aug</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Sept</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Okt</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Nov</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Dez</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Kalender öffnen</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>Sonntag</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Lautstärke</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Ausgang</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Toneinstellungen</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Ton</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>laut stellen</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>stummschalten</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Toneinstellungen</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Keine Ausgabegeräte</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Lautstärke %1</translation>
    </message>
</context>
</TS>